==> risk-center-api-0.5.7-20190815.020821-20-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/InspectSearchParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel
public class InspectSearchParam extends ReqPageQuery {
	private DateRange dateRange;
	@ApiModelProperty("广告id")
	private Integer advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("商品名称")
	private String goodsName;
	@ApiModelProperty("巡检状态 0 待巡检  1 已巡检")
	private Integer inspectStatus;
	@ApiModelProperty("巡检结果 1巡检通过 2巡检拒绝  3下线")
	private Integer inspectResult;    //
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("行业标签")
	private String industryTag;
	@ApiModelProperty("落地页标签")
	private String promoteTag;

	public DateRange getDateRange() {
		return dateRange;
	}

	public void setDateRange(DateRange dateRange) {
		this.dateRange = dateRange;
	}

	public Integer getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Integer advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getGoodsName() {
		return goodsName;
	}

	public void setGoodsName(String goodsName) {
		this.goodsName = goodsName;
	}

	public Integer getInspectStatus() {
		return inspectStatus;
	}

	public void setInspectStatus(Integer inspectStatus) {
		this.inspectStatus = inspectStatus;
	}

	public Integer getInspectResult() {
		return inspectResult;
	}

	public void setInspectResult(Integer inspectResult) {
		this.inspectResult = inspectResult;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getIndustryTag() {
		return industryTag;
	}

	public void setIndustryTag(String industryTag) {
		this.industryTag = industryTag;
	}

	public String getPromoteTag() {
		return promoteTag;
	}

	public void setPromoteTag(String promoteTag) {
		this.promoteTag = promoteTag;
	}
}

==> risk-center-api-0.5.58-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/InspectSearchParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

@ApiModel
public class InspectSearchParam extends ReqPageQuery {
	private DateRange dateRange;
	@ApiModelProperty("广告id")
	private Integer advertId;
	@ApiModelProperty("广告名称")
	private String advertName;
	@ApiModelProperty("商品名称")
	private String goodsName;
	@ApiModelProperty("巡检状态 0 待巡检  1 已巡检")
	private Integer inspectStatus;
	@ApiModelProperty("巡检结果 1巡检通过 2巡检拒绝  3下线")
	private Integer inspectResult;    //
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("代理商名称")
	private String agentName;
	@ApiModelProperty("广告主名称")
	private String advertMaster;
	@ApiModelProperty("行业标签")
	private String industryTag;
	@ApiModelProperty("落地页标签")
	private String promoteTag;
	@ApiModelProperty("广告id集合")
	private List<Long> advertIds;

	public DateRange getDateRange() {
		return dateRange;
	}

	public void setDateRange(DateRange dateRange) {
		this.dateRange = dateRange;
	}

	public Integer getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Integer advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getGoodsName() {
		return goodsName;
	}

	public void setGoodsName(String goodsName) {
		this.goodsName = goodsName;
	}

	public Integer getInspectStatus() {
		return inspectStatus;
	}

	public void setInspectStatus(Integer inspectStatus) {
		this.inspectStatus = inspectStatus;
	}

	public Integer getInspectResult() {
		return inspectResult;
	}

	public void setInspectResult(Integer inspectResult) {
		this.inspectResult = inspectResult;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getIndustryTag() {
		return industryTag;
	}

	public void setIndustryTag(String industryTag) {
		this.industryTag = industryTag;
	}

	public String getPromoteTag() {
		return promoteTag;
	}

	public void setPromoteTag(String promoteTag) {
		this.promoteTag = promoteTag;
	}

	public List<Long> getAdvertIds() {
		return advertIds;
	}

	public void setAdvertIds(List<Long> advertIds) {
		this.advertIds = advertIds;
	}
}
